@@ -138,7 +138,7 @@
 #' \code{\link[evmix:bckden]{qbckden}} gives the quantile function and 
 #' \code{\link[evmix:bckden]{rbckden}} gives a random sample.
 #' 
-#' @note Unlike all the other extreme value mixture model functions the 
+#' @note Unlike most of the other extreme value mixture model functions the 
 #' \code{\link[evmix:bckden]{bckden}} functions have not been vectorised as
 #' this is not appropriate. The main inputs (\code{x}, \code{p} or \code{q})
 #' must be either a scalar or a vector, which also define the output length.
@@ -204,9 +204,11 @@
 #' Jones, M.C. and Henderson, D.A. (2007). Kernel-type density estimation on the unit
 #' interval. Biometrika 94(4), 977-984.
 #' 
-#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}. Based on code
+#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}.
+#' 
+#' @section Acknowledgments: Based on code
 #' by Anna MacDonald produced for MATLAB.
-#'
+#' 
 #' @seealso \code{\link[evmix:kernels]{kernels}}, \code{\link[evmix:kfun]{kfun}},
 #' \code{\link[stats:density]{density}}, \code{\link[stats:bandwidth]{bw.nrd0}}
 #' and \code{\link[ks:kde.1d]{dkde}} in \code{\link[ks:kde.1d]{ks}} package.
@@ -217,6 +219,9 @@
 #' 
 #' @examples
 #' \dontrun{
+#' set.seed(1)
+#' par(mfrow = c(1, 1))
+#' 
 #' n=100
 #' x = rgamma(n, shape = 1, scale = 2)
 #' xx = seq(-0.5, 12, 0.01)
@@ -266,17 +271,16 @@ dbckden <- function(x, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian
   bcmethod = "simple", proper = TRUE, nn = "jf96", offset = NULL, xmax = NULL, log = FALSE) {
 
   # Check properties of inputs
-  check.quant(x, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(x, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw)
   check.kernel(kernel)
   check.bcmethod(bcmethod)
-  check.logic(logicarg = proper)
+  check.logic(proper)
   check.nn(nn)
-  check.posparam(offset, allownull = TRUE)  
-  check.offset(offset, bcmethod)
+  check.offset(offset, bcmethod, allowzero = TRUE)
   check.posparam(xmax, allownull = TRUE)  
-  check.logic(logicarg = log)
+  check.logic(log)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -480,17 +484,16 @@ pbckden <- function(q, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian
   bcmethod = "simple", proper = TRUE, nn = "jf96", offset = NULL, xmax = NULL, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.quant(q, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(q, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw)
   check.kernel(kernel)
   check.bcmethod(bcmethod)
-  check.logic(logicarg = proper)
+  check.logic(proper)
   check.nn(nn)
-  check.posparam(offset, allownull = TRUE)  
-  check.offset(offset, bcmethod)
+  check.offset(offset, bcmethod, allowzero = TRUE)
   check.posparam(xmax, allownull = TRUE)  
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -707,17 +710,16 @@ qbckden <- function(p, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian
   bcmethod = "simple", proper = TRUE, nn = "jf96", offset = NULL, xmax = NULL, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.prob(p, allowmiss = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.prob(p, allowna = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw)
   check.kernel(kernel)
   check.bcmethod(bcmethod)
-  check.logic(logicarg = proper)
+  check.logic(proper)
   check.nn(nn)
-  check.posparam(offset, allownull = TRUE)  
-  check.offset(offset, bcmethod)
-  check.posparam(xmax, allownull = TRUE)  
-  check.logic(logicarg = lower.tail)
+  check.offset(offset, bcmethod, allowzero = TRUE)
+  check.posparam(xmax, allownull = TRUE)
+  check.logic(lower.tail)
     
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -836,65 +838,14 @@ rbckden <- function(n = 1, kerncentres, lambda = NULL, bw = NULL, kernel = "gaus
 
   # Check properties of inputs
   check.n(n)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw)
   check.kernel(kernel)
   check.bcmethod(bcmethod)
-  check.logic(logicarg = proper)
+  check.logic(proper)
   check.nn(nn)
-  check.posparam(offset, allownull = TRUE)  
-  check.offset(offset, bcmethod)
+  check.offset(offset, bcmethod, allowzero = TRUE)
   check.posparam(xmax, allownull = TRUE)  
-    
-  kernel = ifelse(kernel == "rectangular", "uniform", kernel)
-  kernel = ifelse(kernel == "normal", "gaussian", kernel)
 
-  if (any(!is.finite(kerncentres))) warning("non-finite kernel centres are dropped")
-
-  kerncentres = kerncentres[is.finite(kerncentres)]
-
-  if (any(kerncentres < 0)) stop("negative kernel centres not permitted")
-
-  check.quant(kerncentres)
-  nk = length(kerncentres)
-  
-  # if bcmethod does not use standard kernels then lambda must be specified
-  # then bw can be used, but lambda should be defaulted to if available
-  kernelmethods = c("simple", "cutnorm", "renorm", "reflect", "logtrans")
-  if (!(bcmethod %in% kernelmethods)) {
-    if (is.null(lambda))
-      stop(paste("bandwidth bw only relevant for", kernelmethods, collapse = " "))
-  } else {
-    lambda = klambda(bw, kernel, lambda)    
-  }
-
-  if ((bcmethod == "copula") & (lambda >= 1))
-    stop("bandwidth must between (0, 1) for copula method")  
-    
-  upboundmethods = c("beta1", "beta2", "copula")
-  if (!is.null(xmax) & !(bcmethod %in% upboundmethods))
-    warning(paste("xmax only relevant for boundary correction methods", upboundmethods, collapse = " "))
-  
-  if (bcmethod %in% upboundmethods) {
-    if (is.null(xmax)) stop("xmax is NULL")
-    
-    if (max(kerncentres) > xmax) stop("largest kernel centre must be below xmax")
-
-    if (any(kerncentres == 0)) {
-      warning("kernel centres of zero are invalid for gamma or beta method so ignored")
-      kerncentres = kerncentres[kerncentres != 0]
-    }
-
-    if ((bcmethod != "gamma1") & (bcmethod != "gamma2")) {
-      if (any(kerncentres == xmax)) {
-        warning("kernel centres of xmax are invalid for beta or copula method so ignored")
-        kerncentres = kerncentres[kerncentres != xmax]
-      }
-    }
-    # need to recheck there are some valid kernel centres after these exclusions
-    check.quant(kerncentres)
-  }
-
-  qbckden(runif(n), kerncentres = kerncentres, lambda = lambda, kernel = kernel,
-    bcmethod = bcmethod, proper = proper, nn = nn, xmax = xmax, offset = offset)
+  qbckden(runif(n), kerncentres, lambda, bw, kernel, bcmethod, proper, nn, offset, xmax)
 }
