@@ -150,8 +150,12 @@ evmix.diag <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     if ((alpha == 0) | (alpha == 1)) stop("alpha must be in (0, 1)")
   check.n(N)
 
-  if (is.unsorted(modelfit$x, na.rm = TRUE))
+  if (is.unsorted(modelfit$x, na.rm = TRUE)) {
     modelfit$x=sort(modelfit$x)
+  } else {
+    if (modelfit$x[1] > modelfit$x[length(modelfit$x)])
+      modelfit$x = rev(modelfit$x)
+  }
   
   par(mfrow = c(2, 2))
   rlplot(modelfit, upperfocus, alpha, N, legend, ...)
@@ -193,8 +197,12 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     if ((alpha == 0) | (alpha == 1)) stop("alpha must be in (0, 1)")
   check.n(N)
 
-  if (is.unsorted(modelfit$x, na.rm = TRUE))
+  if (is.unsorted(modelfit$x, na.rm = TRUE)) {
     modelfit$x=sort(modelfit$x)
+  } else {
+    if (modelfit$x[1] > modelfit$x[length(modelfit$x)])
+      modelfit$x = rev(modelfit$x)
+  }
   
   nothresh = (modelname == "kden") | (modelname =="bckden") | (modelname =="dwm") | (modelname == "psden")
   twotail = (modelname == "gng") | (modelname == "gngcon") | (modelname == "gkg") | (modelname == "gkgcon")
@@ -239,10 +247,10 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     bckden = qbckden(the.prob, modelfit$kerncentres, modelfit$lambda, bw = NULL,
       modelfit$kernel, modelfit$bcmethod,
       modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpd = qbckdengpd(the.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpd = qbckdengpd(the.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpdcon = qbckdengpdcon(the.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpdcon = qbckdengpdcon(the.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
     betagpd = qbetagpd(the.prob, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -255,10 +263,10 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
     gammagpdcon = qgammagpdcon(the.prob, modelfit$gshape, modelfit$gscale, modelfit$u,
       modelfit$xi, modelfit$phiu),
-    gkg = qgkg(the.prob, modelfit$kerncentres, modelfit$lambda, 
+    gkg = qgkg(the.prob, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-    gkgcon = qgkgcon(the.prob, modelfit$kerncentres, modelfit$lambda, 
+    gkgcon = qgkgcon(the.prob, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
     gng = qgng(the.prob, modelfit$nmean, modelfit$nsd, 
@@ -275,9 +283,9 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     itmgng = qitmgng(the.prob, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
     kden = qkden(the.prob, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-    kdengpd = qkdengpd(the.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpd = qkdengpd(the.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-    kdengpdcon = qkdengpdcon(the.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpdcon = qkdengpdcon(the.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
     mgammagpd = qmgammagpd(the.prob, modelfit$mgshape, modelfit$mgscale, modelfit$mgweight,
       modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -316,10 +324,10 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         gpd = rgpd(n, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
         bckden = rbckden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpd = rbckdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpd = rbckdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpdcon = rbckdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpdcon = rbckdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
         betagpd = rbetagpd(n, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -332,10 +340,10 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
         gammagpdcon = rgammagpdcon(n, modelfit$gshape, modelfit$gscale, modelfit$u,
           modelfit$xi, modelfit$phiu),
-        gkg = rgkg(n, modelfit$kerncentres, modelfit$lambda, 
+        gkg = rgkg(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-        gkgcon = rgkgcon(n, modelfit$kerncentres, modelfit$lambda, 
+        gkgcon = rgkgcon(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
         gng = rgng(n, modelfit$nmean, modelfit$nsd, 
@@ -353,9 +361,9 @@ rlplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         itmgng = ritmgng(n, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
         kden = rkden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-        kdengpd = rkdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpd = rkdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-        kdengpdcon = rkdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpdcon = rkdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
         lognormgpd = rlognormgpd(n, modelfit$lnmean, modelfit$lnsd, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -482,8 +490,12 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     if ((alpha == 0) | (alpha == 1)) stop("alpha must be in (0, 1)")
   check.n(N)
 
-  if (is.unsorted(modelfit$x, na.rm = TRUE))
+  if (is.unsorted(modelfit$x, na.rm = TRUE)) {
     modelfit$x=sort(modelfit$x)
+  } else {
+    if (modelfit$x[1] > modelfit$x[length(modelfit$x)])
+      modelfit$x = rev(modelfit$x)
+  }
   
   nothresh = (modelname == "kden") | (modelname =="bckden") | (modelname =="dwm")
   twotail = (modelname == "gng") | (modelname == "gngcon") | (modelname == "gkg")| (modelname == "gkgcon")
@@ -521,10 +533,10 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     bckden = qbckden(emp.prob, modelfit$kerncentres, modelfit$lambda, bw = NULL,
       modelfit$kernel, modelfit$bcmethod,
       modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpd = qbckdengpd(emp.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpd = qbckdengpd(emp.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpdcon = qbckdengpdcon(emp.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpdcon = qbckdengpdcon(emp.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
     betagpd = qbetagpd(emp.prob, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -537,10 +549,10 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
     gammagpdcon = qgammagpdcon(emp.prob, modelfit$gshape, modelfit$gscale, modelfit$u,
       modelfit$xi, modelfit$phiu),
-    gkg = qgkg(emp.prob, modelfit$kerncentres, modelfit$lambda, 
+    gkg = qgkg(emp.prob, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-    gkgcon = qgkgcon(emp.prob, modelfit$kerncentres, modelfit$lambda, 
+    gkgcon = qgkgcon(emp.prob, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
     gng = qgng(emp.prob, modelfit$nmean, modelfit$nsd, 
@@ -557,9 +569,9 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     itmgng = qitmgng(emp.prob, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
     kden = qkden(emp.prob, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-    kdengpd = qkdengpd(emp.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpd = qkdengpd(emp.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-    kdengpdcon = qkdengpdcon(emp.prob, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpdcon = qkdengpdcon(emp.prob, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
     mgammagpd = qmgammagpd(emp.prob, modelfit$mgshape, modelfit$mgscale, modelfit$mgweight,
       modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -585,10 +597,10 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         gpd = rgpd(n, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
         bckden = rbckden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpd = rbckdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpd = rbckdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpdcon = rbckdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpdcon = rbckdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
         betagpd = rbetagpd(n, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -601,10 +613,10 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
         gammagpdcon = rgammagpdcon(n, modelfit$gshape, modelfit$gscale, modelfit$u,
           modelfit$xi, modelfit$phiu),
-        gkg = rgkg(n, modelfit$kerncentres, modelfit$lambda, 
+        gkg = rgkg(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-        gkgcon = rgkgcon(n, modelfit$kerncentres, modelfit$lambda, 
+        gkgcon = rgkgcon(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
         gng = rgng(n, modelfit$nmean, modelfit$nsd, 
@@ -622,9 +634,9 @@ qplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         itmgng = ritmgng(n, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
         kden = rkden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-        kdengpd = rkdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpd = rkdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-        kdengpdcon = rkdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpdcon = rkdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
         lognormgpd = rlognormgpd(n, modelfit$lnmean, modelfit$lnsd, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -734,8 +746,12 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     if ((alpha == 0) | (alpha == 1)) stop("alpha must be in (0, 1)")
   check.n(N)
 
-  if (is.unsorted(modelfit$x, na.rm = TRUE))
+  if (is.unsorted(modelfit$x, na.rm = TRUE)) {
     modelfit$x=sort(modelfit$x)
+  } else {
+    if (modelfit$x[1] > modelfit$x[length(modelfit$x)])
+      modelfit$x = rev(modelfit$x)
+  }
   
   nothresh = (modelname == "kden") | (modelname =="bckden") | (modelname =="dwm")
   twotail = (modelname == "gng") | (modelname == "gngcon") | (modelname == "gkg") | (modelname == "gkgcon")
@@ -770,10 +786,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     gpd = pgpd(modelfit$x, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
     bckden = pbckden(modelfit$x, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpd = pbckdengpd(modelfit$x, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpd = pbckdengpd(modelfit$x, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel, 
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpdcon = pbckdengpdcon(modelfit$x, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpdcon = pbckdengpdcon(modelfit$x, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel, 
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
     betagpd = pbetagpd(modelfit$x, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -786,10 +802,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
     gammagpdcon = pgammagpdcon(modelfit$x, modelfit$gshape, modelfit$gscale, modelfit$u,
       modelfit$xi, modelfit$phiu),
-    gkg = pgkg(modelfit$x, modelfit$kerncentres, modelfit$lambda, 
+    gkg = pgkg(modelfit$x, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-    gkgcon = pgkgcon(modelfit$x, modelfit$kerncentres, modelfit$lambda, 
+    gkgcon = pgkgcon(modelfit$x, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
     gng = pgng(modelfit$x, modelfit$nmean, modelfit$nsd,
@@ -806,9 +822,9 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
     itmgng = pitmgng(modelfit$x, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
     kden = pkden(modelfit$x, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-    kdengpd = pkdengpd(modelfit$x, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpd = pkdengpd(modelfit$x, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-    kdengpdcon = pkdengpdcon(modelfit$x, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpdcon = pkdengpdcon(modelfit$x, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
     lognormgpd = plognormgpd(modelfit$x, modelfit$lnmean, modelfit$lnsd, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -840,10 +856,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         gpd = rgpd(n, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
         bckden = rbckden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpd = rbckdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpd = rbckdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpdcon = rbckdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpdcon = rbckdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
         betagpd = rbetagpd(n, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -856,10 +872,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
         gammagpdcon = rgammagpdcon(n, modelfit$gshape, modelfit$gscale, modelfit$u,
           modelfit$xi, modelfit$phiu),
-        gkg = rgkg(n, modelfit$kerncentres, modelfit$lambda, 
+        gkg = rgkg(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-        gkgcon = rgkgcon(n, modelfit$kerncentres, modelfit$lambda, 
+        gkgcon = rgkgcon(n, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
         gng = rgng(n, modelfit$nmean, modelfit$nsd, 
@@ -877,9 +893,9 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         itmgng = ritmgng(n, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
         kden = rkden(n, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-        kdengpd = rkdengpd(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpd = rkdengpd(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-        kdengpdcon = rkdengpdcon(n, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpdcon = rkdengpdcon(n, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
         lognormgpd = rlognormgpd(n, modelfit$lnmean, modelfit$lnsd, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -901,10 +917,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         gpd = pgpd(simdata, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
         bckden = pbckden(simdata, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-        bckdengpd = pbckdengpd(simdata, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpd = pbckdengpd(simdata, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel,
           modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),  
-        bckdengpdcon = pbckdengpdcon(simdata, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        bckdengpdcon = pbckdengpdcon(simdata, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel, modelfit$bcmethod,
           modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),  
         betagpd = pbetagpd(simdata, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -917,10 +933,10 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
         gammagpdcon = pgammagpdcon(simdata, modelfit$gshape, modelfit$gscale, modelfit$u,
           modelfit$xi, modelfit$phiu),
-        gkg = pgkg(simdata, modelfit$kerncentres, modelfit$lambda, 
+        gkg = pgkg(simdata, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
-        gkgcon = pgkgcon(simdata, modelfit$kerncentres, modelfit$lambda, 
+        gkgcon = pgkgcon(simdata, modelfit$x, modelfit$lambda, 
           modelfit$ul, modelfit$xil, modelfit$phiul,
           modelfit$ur, modelfit$xir, modelfit$phiur, bw = NULL, modelfit$kernel),
         gng = pgng(simdata, modelfit$nmean, modelfit$nsd, 
@@ -937,9 +953,9 @@ pplot <- function(modelfit, upperfocus = TRUE, alpha = 0.05, N = 1000,
         itmgng = pitmgng(simdata, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
           modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
         kden = pkden(simdata, modelfit$kerncentres, modelfit$lambda, bw = NULL, modelfit$kernel),
-        kdengpd = pkdengpd(simdata, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpd = pkdengpd(simdata, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
-        kdengpdcon = pkdengpdcon(simdata, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+        kdengpdcon = pkdengpdcon(simdata, modelfit$x, modelfit$lambda, modelfit$u,
           modelfit$xi, modelfit$phiu, bw = NULL, modelfit$kernel),
         lognormgpd = plognormgpd(simdata, modelfit$lnmean, modelfit$lnsd, modelfit$u,
           modelfit$sigmau, modelfit$xi, modelfit$phiu),
@@ -1031,8 +1047,12 @@ densplot <- function(modelfit, upperfocus = TRUE, legend = TRUE, ...) {
   check.logic(upperfocus)
   check.logic(legend)
   
-  if (is.unsorted(modelfit$x, na.rm = TRUE))
+  if (is.unsorted(modelfit$x, na.rm = TRUE)) {
     modelfit$x=sort(modelfit$x)
+  } else {
+    if (modelfit$x[1] > modelfit$x[length(modelfit$x)])
+      modelfit$x = rev(modelfit$x)
+  }
 
   nothresh = (modelname == "kden") | (modelname =="bckden") | (modelname =="dwm")
   twotail = (modelname == "gng") | (modelname == "gngcon") | (modelname == "gkg") | (modelname == "gkgcon")
@@ -1067,10 +1087,10 @@ densplot <- function(modelfit, upperfocus = TRUE, legend = TRUE, ...) {
     gpd = dgpd(xx, modelfit$u, modelfit$sigmau, modelfit$xi, modelfit$phiu),
     bckden = dbckden(xx, modelfit$kerncentres, modelfit$lambda, bw=NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpd = dbckdengpd(xx, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpd = dbckdengpd(xx, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw=NULL, modelfit$kernel,
       modelfit$bcmethod, modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
-    bckdengpdcon = dbckdengpdcon(xx, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    bckdengpdcon = dbckdengpdcon(xx, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw=NULL, modelfit$kernel, modelfit$bcmethod,
       modelfit$proper, modelfit$nn, modelfit$offset, modelfit$xmax),
     betagpd = dbetagpd(xx, modelfit$bshape1, modelfit$bshape2, modelfit$u,
@@ -1083,10 +1103,10 @@ densplot <- function(modelfit, upperfocus = TRUE, legend = TRUE, ...) {
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
     gammagpdcon = dgammagpdcon(xx, modelfit$gshape, modelfit$gscale, modelfit$u,
       modelfit$xi, modelfit$phiu),
-    gkg = dgkg(xx, modelfit$kerncentres, modelfit$lambda, 
+    gkg = dgkg(xx, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$sigmaur, modelfit$xir, modelfit$phiur, bw=NULL, modelfit$kernel),
-    gkgcon = dgkgcon(xx, modelfit$kerncentres, modelfit$lambda, 
+    gkgcon = dgkgcon(xx, modelfit$x, modelfit$lambda, 
       modelfit$ul, modelfit$xil, modelfit$phiul,
       modelfit$ur, modelfit$xir, modelfit$phiur, bw=NULL, modelfit$kernel),
     gng = dgng(xx, modelfit$nmean, modelfit$nsd, 
@@ -1103,9 +1123,9 @@ densplot <- function(modelfit, upperfocus = TRUE, legend = TRUE, ...) {
     itmgng = ditmgng(xx, modelfit$nmean, modelfit$nsd, modelfit$epsilon, 
       modelfit$ul, modelfit$sigmaul, modelfit$xil, modelfit$ur, modelfit$sigmaur, modelfit$xir),
     kden = dkden(xx, modelfit$kerncentres, modelfit$lambda, bw=NULL, modelfit$kernel),
-    kdengpd = dkdengpd(xx, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpd = dkdengpd(xx, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu, bw=NULL, modelfit$kernel),
-    kdengpdcon = dkdengpdcon(xx, modelfit$kerncentres, modelfit$lambda, modelfit$u,
+    kdengpdcon = dkdengpdcon(xx, modelfit$x, modelfit$lambda, modelfit$u,
       modelfit$xi, modelfit$phiu, bw=NULL, modelfit$kernel),
     lognormgpd = dlognormgpd(xx, modelfit$lnmean, modelfit$lnsd, modelfit$u,
       modelfit$sigmau, modelfit$xi, modelfit$phiu),
